@@ -3,7 +3,7 @@ __version__ = '0.0.6'
 
 
 from wavencoder.models.wav2vec import Wav2Vec
-# from wavencoder.models.wav2vec2 import Wav2Vec2Model
+from wavencoder.models.wav2vec2 import Wav2Vec2
 from wavencoder.models.sincnet import SincNet, SincConvLayer
 from wavencoder.models.lstm_classifier import LSTM_Classifier
 from wavencoder.models.lstm_classifier import LSTM_Attn_Classifier
