@@ -4,4 +4,7 @@ from wavencoder.transforms.speed import SpeedChange
 from wavencoder.transforms.clip import Clipping
 from wavencoder.transforms.pad_crop import Pad, Crop, PadCrop
 from wavencoder.transforms.reverberation import Reverberation
-from wavencoder.transforms.compose import Compose
\ No newline at end of file
+from wavencoder.transforms.compose import Compose
+from wavencoder.transforms.timeshift import TimeShift
+
+from wavencoder.transforms.spec_augment import TimeMask, FrequencyMask
\ No newline at end of file
